===
API
===


Caching Request Data
--------------------

.. autofunction:: faux.client.get

.. autofunction:: faux.client.post

.. autofunction:: faux.client.put

.. autofunction:: faux.client.delete


Mocking Servers
---------------

.. autoclass:: faux.server.Server
   :members:


.. autoclass:: faux.server.Instance
   :members:

